@@ -394,8 +394,12 @@ class LoggingCallback(KeyedCallback):
 
 
 class ProgressBarCallback(KeyedCallback):
-    """A progress bar optimization logger."""
+    """A progress bar optimization logger.
 
+    Args:
+        label(str): a prefix label to identify the experiment currently
+            running.
+    """
     def __init__(self, keys=None, val_keys=None, smoothing=0.99, label=None):
         super(ProgressBarCallback, self).__init__(
             keys=keys, val_keys=val_keys, smoothing=smoothing)
